# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/video/proto/video_h265cfg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/video/proto/video_h265cfg.proto',
  package='apollo.drivers.video.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/drivers/video/proto/video_h265cfg.proto\x12\x1b\x61pollo.drivers.video.config\"\xf0\x05\n\x10\x43\x61meraH265Config\x12\x10\n\x08udp_port\x18\x01 \x02(\r\x12\x10\n\x08\x66rame_id\x18\x02 \x02(\t\x12\x1a\n\x0cpixel_format\x18\x03 \x02(\t:\x04yuyv\x12\x0e\n\x06record\x18\x04 \x02(\r\x12\r\n\x05width\x18\x05 \x02(\r\x12\x0e\n\x06height\x18\x06 \x02(\r\x12\x12\n\nframe_rate\x18\x07 \x02(\r\x12\x19\n\nmonochrome\x18\x08 \x02(\x08:\x05\x66\x61lse\x12\x16\n\nbrightness\x18\t \x02(\x05:\x02-1\x12\x14\n\x08\x63ontrast\x18\n \x02(\x05:\x02-1\x12\x16\n\nsaturation\x18\x0b \x02(\x05:\x02-1\x12\x15\n\tsharpness\x18\x0c \x02(\x05:\x02-1\x12\x10\n\x04gain\x18\r \x02(\x05:\x02-1\x12\x19\n\nauto_focus\x18\x0e \x02(\x08:\x05\x66\x61lse\x12\x11\n\x05\x66ocus\x18\x0f \x02(\x05:\x02-1\x12\x1b\n\rauto_exposure\x18\x10 \x02(\x08:\x04true\x12\x15\n\x08\x65xposure\x18\x11 \x02(\x05:\x03\x31\x30\x30\x12 \n\x12\x61uto_white_balance\x18\x12 \x02(\x08:\x04true\x12\x1b\n\rwhite_balance\x18\x13 \x02(\x05:\x04\x34\x30\x30\x30\x12\x1a\n\x0f\x62ytes_per_pixel\x18\x14 \x02(\r:\x01\x33\x12\x1b\n\rtrigger_param\x18\x15 \x02(\t:\x04\x66\x32\x66\x66\x12\x1d\n\x11metric_error_code\x18\x16 \x02(\r:\x02\x31\x31\x12\x1b\n\x0f\x66pga_dev_number\x18\x17 \x02(\x05:\x02-1\x12\x1d\n\x11\x63\x61mera_seq_number\x18\x18 \x02(\x05:\x02-1\x12S\n\rcompress_conf\x18\x19 \x01(\x0b\x32<.apollo.drivers.video.config.CameraH265Config.CompressConfig\x1a\x45\n\x0e\x43ompressConfig\x12\x16\n\x0eoutput_channel\x18\x01 \x01(\t\x12\x1b\n\x0fimage_pool_size\x18\x02 \x01(\r:\x02\x32\x30'
)




_CAMERAH265CONFIG_COMPRESSCONFIG = _descriptor.Descriptor(
  name='CompressConfig',
  full_name='apollo.drivers.video.config.CameraH265Config.CompressConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_channel', full_name='apollo.drivers.video.config.CameraH265Config.CompressConfig.output_channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_pool_size', full_name='apollo.drivers.video.config.CameraH265Config.CompressConfig.image_pool_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=833,
)

_CAMERAH265CONFIG = _descriptor.Descriptor(
  name='CameraH265Config',
  full_name='apollo.drivers.video.config.CameraH265Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='udp_port', full_name='apollo.drivers.video.config.CameraH265Config.udp_port', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.video.config.CameraH265Config.frame_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pixel_format', full_name='apollo.drivers.video.config.CameraH265Config.pixel_format', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=b"yuyv".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record', full_name='apollo.drivers.video.config.CameraH265Config.record', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.video.config.CameraH265Config.width', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.drivers.video.config.CameraH265Config.height', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_rate', full_name='apollo.drivers.video.config.CameraH265Config.frame_rate', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monochrome', full_name='apollo.drivers.video.config.CameraH265Config.monochrome', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brightness', full_name='apollo.drivers.video.config.CameraH265Config.brightness', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contrast', full_name='apollo.drivers.video.config.CameraH265Config.contrast', index=9,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saturation', full_name='apollo.drivers.video.config.CameraH265Config.saturation', index=10,
      number=11, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sharpness', full_name='apollo.drivers.video.config.CameraH265Config.sharpness', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain', full_name='apollo.drivers.video.config.CameraH265Config.gain', index=12,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_focus', full_name='apollo.drivers.video.config.CameraH265Config.auto_focus', index=13,
      number=14, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='focus', full_name='apollo.drivers.video.config.CameraH265Config.focus', index=14,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_exposure', full_name='apollo.drivers.video.config.CameraH265Config.auto_exposure', index=15,
      number=16, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exposure', full_name='apollo.drivers.video.config.CameraH265Config.exposure', index=16,
      number=17, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_white_balance', full_name='apollo.drivers.video.config.CameraH265Config.auto_white_balance', index=17,
      number=18, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='white_balance', full_name='apollo.drivers.video.config.CameraH265Config.white_balance', index=18,
      number=19, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=4000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_per_pixel', full_name='apollo.drivers.video.config.CameraH265Config.bytes_per_pixel', index=19,
      number=20, type=13, cpp_type=3, label=2,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_param', full_name='apollo.drivers.video.config.CameraH265Config.trigger_param', index=20,
      number=21, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=b"f2ff".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_error_code', full_name='apollo.drivers.video.config.CameraH265Config.metric_error_code', index=21,
      number=22, type=13, cpp_type=3, label=2,
      has_default_value=True, default_value=11,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fpga_dev_number', full_name='apollo.drivers.video.config.CameraH265Config.fpga_dev_number', index=22,
      number=23, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_seq_number', full_name='apollo.drivers.video.config.CameraH265Config.camera_seq_number', index=23,
      number=24, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compress_conf', full_name='apollo.drivers.video.config.CameraH265Config.compress_conf', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CAMERAH265CONFIG_COMPRESSCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=833,
)

_CAMERAH265CONFIG_COMPRESSCONFIG.containing_type = _CAMERAH265CONFIG
_CAMERAH265CONFIG.fields_by_name['compress_conf'].message_type = _CAMERAH265CONFIG_COMPRESSCONFIG
DESCRIPTOR.message_types_by_name['CameraH265Config'] = _CAMERAH265CONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraH265Config = _reflection.GeneratedProtocolMessageType('CameraH265Config', (_message.Message,), {

  'CompressConfig' : _reflection.GeneratedProtocolMessageType('CompressConfig', (_message.Message,), {
    'DESCRIPTOR' : _CAMERAH265CONFIG_COMPRESSCONFIG,
    '__module__' : 'modules.drivers.video.proto.video_h265cfg_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.video.config.CameraH265Config.CompressConfig)
    })
  ,
  'DESCRIPTOR' : _CAMERAH265CONFIG,
  '__module__' : 'modules.drivers.video.proto.video_h265cfg_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.video.config.CameraH265Config)
  })
_sym_db.RegisterMessage(CameraH265Config)
_sym_db.RegisterMessage(CameraH265Config.CompressConfig)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/hesai/proto/config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.hesai.proto import hesai_pb2 as modules_dot_drivers_dot_hesai_dot_proto_dot_hesai__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/hesai/proto/config.proto',
  package='apollo.drivers.hesai',
  syntax='proto2',
  serialized_pb=_b('\n(modules/drivers/hesai/proto/config.proto\x12\x14\x61pollo.drivers.hesai\x1a\'modules/drivers/hesai/proto/hesai.proto\"\xc6\x02\n\x06\x43onfig\x12*\n\x05model\x18\x01 \x01(\x0e\x32\x1b.apollo.drivers.hesai.Model\x12\x19\n\x02ip\x18\x02 \x01(\t:\r192.168.20.13\x12\x17\n\x0flidar_recv_port\x18\x03 \x01(\r\x12\x15\n\rgps_recv_port\x18\x04 \x01(\r\x12\x13\n\x0bstart_angle\x18\x05 \x01(\r\x12\x1a\n\x12pointcloud_channel\x18\x06 \x01(\t\x12\x11\n\ttime_zone\x18\x07 \x01(\r\x12\x10\n\x08\x66rame_id\x18\x08 \x01(\t\x12\x14\n\x0cscan_channel\x18\t \x01(\t\x12#\n\x15is_online_calibration\x18\x0b \x01(\x08:\x04true\x12\x18\n\x10\x63\x61libration_file\x18\x0c \x01(\t\x12\x1a\n\x0ctcp_cmd_port\x18\r \x01(\r:\x04\x39\x33\x34\x37')
  ,
  dependencies=[modules_dot_drivers_dot_hesai_dot_proto_dot_hesai__pb2.DESCRIPTOR,])




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='apollo.drivers.hesai.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.drivers.hesai.Config.model', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='apollo.drivers.hesai.Config.ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("192.168.20.13").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lidar_recv_port', full_name='apollo.drivers.hesai.Config.lidar_recv_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gps_recv_port', full_name='apollo.drivers.hesai.Config.gps_recv_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_angle', full_name='apollo.drivers.hesai.Config.start_angle', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pointcloud_channel', full_name='apollo.drivers.hesai.Config.pointcloud_channel', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='apollo.drivers.hesai.Config.time_zone', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.hesai.Config.frame_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_channel', full_name='apollo.drivers.hesai.Config.scan_channel', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_online_calibration', full_name='apollo.drivers.hesai.Config.is_online_calibration', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_file', full_name='apollo.drivers.hesai.Config.calibration_file', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tcp_cmd_port', full_name='apollo.drivers.hesai.Config.tcp_cmd_port', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=9347,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=434,
)

_CONFIG.fields_by_name['model'].enum_type = modules_dot_drivers_dot_hesai_dot_proto_dot_hesai__pb2._MODEL
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), dict(
  DESCRIPTOR = _CONFIG,
  __module__ = 'modules.drivers.hesai.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.hesai.Config)
  ))
_sym_db.RegisterMessage(Config)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/network_model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.prediction.proto import network_layers_pb2 as modules_dot_prediction_dot_proto_dot_network__layers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/network_model.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,modules/prediction/proto/network_model.proto\x12\x11\x61pollo.prediction\x1a-modules/prediction/proto/network_layers.proto\"q\n\x12VerificationSample\x12\x34\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\".apollo.prediction.TensorParameter\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x12\x10\n\x08\x64istance\x18\x03 \x01(\x02\"B\n\x0bPerformance\x12\x10\n\x08\x61\x63\x63uracy\x18\x01 \x03(\x02\x12\x0e\n\x06recall\x18\x02 \x03(\x02\x12\x11\n\tprecision\x18\x03 \x03(\x02\"\xea\x01\n\x0cNetParameter\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n\x06layers\x18\x03 \x03(\x0b\x32!.apollo.prediction.LayerParameter\x12\x43\n\x14verification_samples\x18\x04 \x03(\x0b\x32%.apollo.prediction.VerificationSample\x12\x33\n\x0bperformance\x18\x05 \x01(\x0b\x32\x1e.apollo.prediction.Performance\x12\x13\n\x0btime_dumped\x18\x06 \x01(\x02'
  ,
  dependencies=[modules_dot_prediction_dot_proto_dot_network__layers__pb2.DESCRIPTOR,])




_VERIFICATIONSAMPLE = _descriptor.Descriptor(
  name='VerificationSample',
  full_name='apollo.prediction.VerificationSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='apollo.prediction.VerificationSample.features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.prediction.VerificationSample.probability', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.prediction.VerificationSample.distance', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=227,
)


_PERFORMANCE = _descriptor.Descriptor(
  name='Performance',
  full_name='apollo.prediction.Performance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='apollo.prediction.Performance.accuracy', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recall', full_name='apollo.prediction.Performance.recall', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precision', full_name='apollo.prediction.Performance.precision', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=295,
)


_NETPARAMETER = _descriptor.Descriptor(
  name='NetParameter',
  full_name='apollo.prediction.NetParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.NetParameter.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.prediction.NetParameter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layers', full_name='apollo.prediction.NetParameter.layers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verification_samples', full_name='apollo.prediction.NetParameter.verification_samples', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='performance', full_name='apollo.prediction.NetParameter.performance', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_dumped', full_name='apollo.prediction.NetParameter.time_dumped', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=532,
)

_VERIFICATIONSAMPLE.fields_by_name['features'].message_type = modules_dot_prediction_dot_proto_dot_network__layers__pb2._TENSORPARAMETER
_NETPARAMETER.fields_by_name['layers'].message_type = modules_dot_prediction_dot_proto_dot_network__layers__pb2._LAYERPARAMETER
_NETPARAMETER.fields_by_name['verification_samples'].message_type = _VERIFICATIONSAMPLE
_NETPARAMETER.fields_by_name['performance'].message_type = _PERFORMANCE
DESCRIPTOR.message_types_by_name['VerificationSample'] = _VERIFICATIONSAMPLE
DESCRIPTOR.message_types_by_name['Performance'] = _PERFORMANCE
DESCRIPTOR.message_types_by_name['NetParameter'] = _NETPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VerificationSample = _reflection.GeneratedProtocolMessageType('VerificationSample', (_message.Message,), {
  'DESCRIPTOR' : _VERIFICATIONSAMPLE,
  '__module__' : 'modules.prediction.proto.network_model_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.VerificationSample)
  })
_sym_db.RegisterMessage(VerificationSample)

Performance = _reflection.GeneratedProtocolMessageType('Performance', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMANCE,
  '__module__' : 'modules.prediction.proto.network_model_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Performance)
  })
_sym_db.RegisterMessage(Performance)

NetParameter = _reflection.GeneratedProtocolMessageType('NetParameter', (_message.Message,), {
  'DESCRIPTOR' : _NETPARAMETER,
  '__module__' : 'modules.prediction.proto.network_model_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.NetParameter)
  })
_sym_db.RegisterMessage(NetParameter)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/chassis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import vehicle_signal_pb2 as modules_dot_common_dot_proto_dot_vehicle__signal__pb2
from modules.common.proto import drive_state_pb2 as modules_dot_common_dot_proto_dot_drive__state__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.configs.proto import vehicle_config_pb2 as modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/chassis.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"modules/canbus/proto/chassis.proto\x12\rapollo.canbus\x1a!modules/common/proto/header.proto\x1a)modules/common/proto/vehicle_signal.proto\x1a&modules/common/proto/drive_state.proto\x1a#modules/common/proto/geometry.proto\x1a\x31modules/common/configs/proto/vehicle_config.proto\"\xec\x0c\n\x07\x43hassis\x12\x16\n\x0e\x65ngine_started\x18\x03 \x01(\x08\x12\x17\n\nengine_rpm\x18\x04 \x01(\x02:\x03nan\x12\x16\n\tspeed_mps\x18\x05 \x01(\x02:\x03nan\x12\x17\n\nodometer_m\x18\x06 \x01(\x02:\x03nan\x12\x14\n\x0c\x66uel_range_m\x18\x07 \x01(\x05\x12 \n\x13throttle_percentage\x18\x08 \x01(\x02:\x03nan\x12\x1d\n\x10\x62rake_percentage\x18\t \x01(\x02:\x03nan\x12 \n\x13steering_percentage\x18\x0b \x01(\x02:\x03nan\x12\x1f\n\x12steering_torque_nm\x18\x0c \x01(\x02:\x03nan\x12\x15\n\rparking_brake\x18\r \x01(\x08\x12\x1c\n\x10high_beam_signal\x18\x0e \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0flow_beam_signal\x18\x0f \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10left_turn_signal\x18\x10 \x01(\x08\x42\x02\x18\x01\x12\x1d\n\x11right_turn_signal\x18\x11 \x01(\x08\x42\x02\x18\x01\x12\x10\n\x04horn\x18\x12 \x01(\x08\x42\x02\x18\x01\x12\r\n\x05wiper\x18\x13 \x01(\x08\x12\x1c\n\x10\x64isengage_status\x18\x14 \x01(\x08\x42\x02\x18\x01\x12I\n\x0c\x64riving_mode\x18\x15 \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingMode:\x0f\x43OMPLETE_MANUAL\x12>\n\nerror_code\x18\x16 \x01(\x0e\x32 .apollo.canbus.Chassis.ErrorCode:\x08NO_ERROR\x12:\n\rgear_location\x18\x17 \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12\x1a\n\x12steering_timestamp\x18\x18 \x01(\x01\x12%\n\x06header\x18\x19 \x01(\x0b\x32\x15.apollo.common.Header\x12\x1d\n\x12\x63hassis_error_mask\x18\x1a \x01(\x05:\x01\x30\x12,\n\x06signal\x18\x1b \x01(\x0b\x32\x1c.apollo.common.VehicleSignal\x12.\n\x0b\x63hassis_gps\x18\x1c \x01(\x0b\x32\x19.apollo.canbus.ChassisGPS\x12\x32\n\rengage_advice\x18\x1d \x01(\x0b\x32\x1b.apollo.common.EngageAdvice\x12.\n\x0bwheel_speed\x18\x1e \x01(\x0b\x32\x19.apollo.canbus.WheelSpeed\x12)\n\x08surround\x18\x1f \x01(\x0b\x32\x17.apollo.canbus.Surround\x12+\n\x07license\x18  \x01(\x0b\x32\x16.apollo.canbus.LicenseB\x02\x18\x01\x12,\n\nvehicle_id\x18! \x01(\x0b\x32\x18.apollo.common.VehicleID\x12\"\n\x16\x62\x61ttery_soc_percentage\x18\" \x01(\x05:\x02-1\"y\n\x0b\x44rivingMode\x12\x13\n\x0f\x43OMPLETE_MANUAL\x10\x00\x12\x17\n\x13\x43OMPLETE_AUTO_DRIVE\x10\x01\x12\x13\n\x0f\x41UTO_STEER_ONLY\x10\x02\x12\x13\n\x0f\x41UTO_SPEED_ONLY\x10\x03\x12\x12\n\x0e\x45MERGENCY_MODE\x10\x04\"\x80\x02\n\tErrorCode\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x15\n\x11\x43MD_NOT_IN_PERIOD\x10\x01\x12\x11\n\rCHASSIS_ERROR\x10\x02\x12\x1a\n\x16\x43HASSIS_ERROR_ON_STEER\x10\x06\x12\x1a\n\x16\x43HASSIS_ERROR_ON_BRAKE\x10\x07\x12\x1d\n\x19\x43HASSIS_ERROR_ON_THROTTLE\x10\x08\x12\x19\n\x15\x43HASSIS_ERROR_ON_GEAR\x10\t\x12\x17\n\x13MANUAL_INTERVENTION\x10\x03\x12\x1d\n\x19\x43HASSIS_CAN_NOT_IN_PERIOD\x10\x04\x12\x11\n\rUNKNOWN_ERROR\x10\x05\"\x83\x01\n\x0cGearPosition\x12\x10\n\x0cGEAR_NEUTRAL\x10\x00\x12\x0e\n\nGEAR_DRIVE\x10\x01\x12\x10\n\x0cGEAR_REVERSE\x10\x02\x12\x10\n\x0cGEAR_PARKING\x10\x03\x12\x0c\n\x08GEAR_LOW\x10\x04\x12\x10\n\x0cGEAR_INVALID\x10\x05\x12\r\n\tGEAR_NONE\x10\x06\"\x89\x03\n\nChassisGPS\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x11\n\tgps_valid\x18\x03 \x01(\x08\x12\x0c\n\x04year\x18\x04 \x01(\x05\x12\r\n\x05month\x18\x05 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x06 \x01(\x05\x12\r\n\x05hours\x18\x07 \x01(\x05\x12\x0f\n\x07minutes\x18\x08 \x01(\x05\x12\x0f\n\x07seconds\x18\t \x01(\x05\x12\x19\n\x11\x63ompass_direction\x18\n \x01(\x01\x12\x0c\n\x04pdop\x18\x0b \x01(\x01\x12\x14\n\x0cis_gps_fault\x18\x0c \x01(\x08\x12\x13\n\x0bis_inferred\x18\r \x01(\x08\x12\x10\n\x08\x61ltitude\x18\x0e \x01(\x01\x12\x0f\n\x07heading\x18\x0f \x01(\x01\x12\x0c\n\x04hdop\x18\x10 \x01(\x01\x12\x0c\n\x04vdop\x18\x11 \x01(\x01\x12*\n\x07quality\x18\x12 \x01(\x0e\x32\x19.apollo.canbus.GpsQuality\x12\x16\n\x0enum_satellites\x18\x13 \x01(\x05\x12\x11\n\tgps_speed\x18\x14 \x01(\x01\"\x8e\x05\n\nWheelSpeed\x12$\n\x15is_wheel_spd_rr_valid\x18\x01 \x01(\x08:\x05\x66\x61lse\x12M\n\x12wheel_direction_rr\x18\x02 \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType:\x07INVALID\x12\x17\n\x0cwheel_spd_rr\x18\x03 \x01(\x01:\x01\x30\x12$\n\x15is_wheel_spd_rl_valid\x18\x04 \x01(\x08:\x05\x66\x61lse\x12M\n\x12wheel_direction_rl\x18\x05 \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType:\x07INVALID\x12\x17\n\x0cwheel_spd_rl\x18\x06 \x01(\x01:\x01\x30\x12$\n\x15is_wheel_spd_fr_valid\x18\x07 \x01(\x08:\x05\x66\x61lse\x12M\n\x12wheel_direction_fr\x18\x08 \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType:\x07INVALID\x12\x17\n\x0cwheel_spd_fr\x18\t \x01(\x01:\x01\x30\x12$\n\x15is_wheel_spd_fl_valid\x18\n \x01(\x08:\x05\x66\x61lse\x12M\n\x12wheel_direction_fl\x18\x0b \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType:\x07INVALID\x12\x17\n\x0cwheel_spd_fl\x18\x0c \x01(\x01:\x01\x30\"H\n\x0eWheelSpeedType\x12\x0b\n\x07\x46ORWARD\x10\x00\x12\x0c\n\x08\x42\x41\x43KWARD\x10\x01\x12\x0e\n\nSTANDSTILL\x10\x02\x12\x0b\n\x07INVALID\x10\x03\"p\n\x05Sonar\x12\r\n\x05range\x18\x01 \x01(\x01\x12+\n\x0btranslation\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12+\n\x08rotation\x18\x03 \x01(\x0b\x32\x19.apollo.common.Quaternion\"\xe4\x04\n\x08Surround\x12 \n\x18\x63ross_traffic_alert_left\x18\x01 \x01(\x08\x12(\n cross_traffic_alert_left_enabled\x18\x02 \x01(\x08\x12\x1d\n\x15\x62lind_spot_left_alert\x18\x03 \x01(\x08\x12%\n\x1d\x62lind_spot_left_alert_enabled\x18\x04 \x01(\x08\x12!\n\x19\x63ross_traffic_alert_right\x18\x05 \x01(\x08\x12)\n!cross_traffic_alert_right_enabled\x18\x06 \x01(\x08\x12\x1e\n\x16\x62lind_spot_right_alert\x18\x07 \x01(\x08\x12&\n\x1e\x62lind_spot_right_alert_enabled\x18\x08 \x01(\x08\x12\x0f\n\x07sonar00\x18\t \x01(\x01\x12\x0f\n\x07sonar01\x18\n \x01(\x01\x12\x0f\n\x07sonar02\x18\x0b \x01(\x01\x12\x0f\n\x07sonar03\x18\x0c \x01(\x01\x12\x0f\n\x07sonar04\x18\r \x01(\x01\x12\x0f\n\x07sonar05\x18\x0e \x01(\x01\x12\x0f\n\x07sonar06\x18\x0f \x01(\x01\x12\x0f\n\x07sonar07\x18\x10 \x01(\x01\x12\x0f\n\x07sonar08\x18\x11 \x01(\x01\x12\x0f\n\x07sonar09\x18\x12 \x01(\x01\x12\x0f\n\x07sonar10\x18\x13 \x01(\x01\x12\x0f\n\x07sonar11\x18\x14 \x01(\x01\x12\x15\n\rsonar_enabled\x18\x15 \x01(\x08\x12\x13\n\x0bsonar_fault\x18\x16 \x01(\x08\x12\x13\n\x0bsonar_range\x18\x17 \x03(\x01\x12#\n\x05sonar\x18\x18 \x03(\x0b\x32\x14.apollo.canbus.Sonar\"\x1a\n\x07License\x12\x0f\n\x03vin\x18\x01 \x01(\tB\x02\x18\x01*A\n\nGpsQuality\x12\n\n\x06\x46IX_NO\x10\x00\x12\n\n\x06\x46IX_2D\x10\x01\x12\n\n\x06\x46IX_3D\x10\x02\x12\x0f\n\x0b\x46IX_INVALID\x10\x03'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_vehicle__signal__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_drive__state__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2.DESCRIPTOR,])

_GPSQUALITY = _descriptor.EnumDescriptor(
  name='GpsQuality',
  full_name='apollo.canbus.GpsQuality',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIX_NO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIX_2D', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIX_3D', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIX_INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3716,
  serialized_end=3781,
)
_sym_db.RegisterEnumDescriptor(_GPSQUALITY)

GpsQuality = enum_type_wrapper.EnumTypeWrapper(_GPSQUALITY)
FIX_NO = 0
FIX_2D = 1
FIX_3D = 2
FIX_INVALID = 3


_CHASSIS_DRIVINGMODE = _descriptor.EnumDescriptor(
  name='DrivingMode',
  full_name='apollo.canbus.Chassis.DrivingMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPLETE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE_AUTO_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_STEER_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_SPEED_ONLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_MODE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1390,
  serialized_end=1511,
)
_sym_db.RegisterEnumDescriptor(_CHASSIS_DRIVINGMODE)

_CHASSIS_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='apollo.canbus.Chassis.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_NOT_IN_PERIOD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_ERROR_ON_STEER', index=3, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_ERROR_ON_BRAKE', index=4, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_ERROR_ON_THROTTLE', index=5, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_ERROR_ON_GEAR', index=6, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INTERVENTION', index=7, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_CAN_NOT_IN_PERIOD', index=8, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=9, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1514,
  serialized_end=1770,
)
_sym_db.RegisterEnumDescriptor(_CHASSIS_ERRORCODE)

_CHASSIS_GEARPOSITION = _descriptor.EnumDescriptor(
  name='GearPosition',
  full_name='apollo.canbus.Chassis.GearPosition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_NEUTRAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_REVERSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_PARKING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_INVALID', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_NONE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1773,
  serialized_end=1904,
)
_sym_db.RegisterEnumDescriptor(_CHASSIS_GEARPOSITION)

_WHEELSPEED_WHEELSPEEDTYPE = _descriptor.EnumDescriptor(
  name='WheelSpeedType',
  full_name='apollo.canbus.WheelSpeed.WheelSpeedType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STANDSTILL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2885,
  serialized_end=2957,
)
_sym_db.RegisterEnumDescriptor(_WHEELSPEED_WHEELSPEEDTYPE)


_CHASSIS = _descriptor.Descriptor(
  name='Chassis',
  full_name='apollo.canbus.Chassis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_started', full_name='apollo.canbus.Chassis.engine_started', index=0,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_rpm', full_name='apollo.canbus.Chassis.engine_rpm', index=1,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_mps', full_name='apollo.canbus.Chassis.speed_mps', index=2,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='odometer_m', full_name='apollo.canbus.Chassis.odometer_m', index=3,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuel_range_m', full_name='apollo.canbus.Chassis.fuel_range_m', index=4,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_percentage', full_name='apollo.canbus.Chassis.throttle_percentage', index=5,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_percentage', full_name='apollo.canbus.Chassis.brake_percentage', index=6,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_percentage', full_name='apollo.canbus.Chassis.steering_percentage', index=7,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_torque_nm', full_name='apollo.canbus.Chassis.steering_torque_nm', index=8,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake', full_name='apollo.canbus.Chassis.parking_brake', index=9,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_beam_signal', full_name='apollo.canbus.Chassis.high_beam_signal', index=10,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_beam_signal', full_name='apollo.canbus.Chassis.low_beam_signal', index=11,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn_signal', full_name='apollo.canbus.Chassis.left_turn_signal', index=12,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn_signal', full_name='apollo.canbus.Chassis.right_turn_signal', index=13,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn', full_name='apollo.canbus.Chassis.horn', index=14,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper', full_name='apollo.canbus.Chassis.wiper', index=15,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disengage_status', full_name='apollo.canbus.Chassis.disengage_status', index=16,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.canbus.Chassis.driving_mode', index=17,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.canbus.Chassis.error_code', index=18,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_location', full_name='apollo.canbus.Chassis.gear_location', index=19,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_timestamp', full_name='apollo.canbus.Chassis.steering_timestamp', index=20,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.canbus.Chassis.header', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis_error_mask', full_name='apollo.canbus.Chassis.chassis_error_mask', index=22,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.canbus.Chassis.signal', index=23,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis_gps', full_name='apollo.canbus.Chassis.chassis_gps', index=24,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engage_advice', full_name='apollo.canbus.Chassis.engage_advice', index=25,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_speed', full_name='apollo.canbus.Chassis.wheel_speed', index=26,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surround', full_name='apollo.canbus.Chassis.surround', index=27,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='license', full_name='apollo.canbus.Chassis.license', index=28,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_id', full_name='apollo.canbus.Chassis.vehicle_id', index=29,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_soc_percentage', full_name='apollo.canbus.Chassis.battery_soc_percentage', index=30,
      number=34, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHASSIS_DRIVINGMODE,
    _CHASSIS_ERRORCODE,
    _CHASSIS_GEARPOSITION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=1904,
)


_CHASSISGPS = _descriptor.Descriptor(
  name='ChassisGPS',
  full_name='apollo.canbus.ChassisGPS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='apollo.canbus.ChassisGPS.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='apollo.canbus.ChassisGPS.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_valid', full_name='apollo.canbus.ChassisGPS.gps_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.canbus.ChassisGPS.year', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.canbus.ChassisGPS.month', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.canbus.ChassisGPS.day', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hours', full_name='apollo.canbus.ChassisGPS.hours', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes', full_name='apollo.canbus.ChassisGPS.minutes', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='apollo.canbus.ChassisGPS.seconds', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compass_direction', full_name='apollo.canbus.ChassisGPS.compass_direction', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdop', full_name='apollo.canbus.ChassisGPS.pdop', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_gps_fault', full_name='apollo.canbus.ChassisGPS.is_gps_fault', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_inferred', full_name='apollo.canbus.ChassisGPS.is_inferred', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='apollo.canbus.ChassisGPS.altitude', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.canbus.ChassisGPS.heading', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hdop', full_name='apollo.canbus.ChassisGPS.hdop', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdop', full_name='apollo.canbus.ChassisGPS.vdop', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.canbus.ChassisGPS.quality', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_satellites', full_name='apollo.canbus.ChassisGPS.num_satellites', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_speed', full_name='apollo.canbus.ChassisGPS.gps_speed', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1907,
  serialized_end=2300,
)


_WHEELSPEED = _descriptor.Descriptor(
  name='WheelSpeed',
  full_name='apollo.canbus.WheelSpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_rr_valid', full_name='apollo.canbus.WheelSpeed.is_wheel_spd_rr_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_rr', full_name='apollo.canbus.WheelSpeed.wheel_direction_rr', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_rr', full_name='apollo.canbus.WheelSpeed.wheel_spd_rr', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_rl_valid', full_name='apollo.canbus.WheelSpeed.is_wheel_spd_rl_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_rl', full_name='apollo.canbus.WheelSpeed.wheel_direction_rl', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_rl', full_name='apollo.canbus.WheelSpeed.wheel_spd_rl', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_fr_valid', full_name='apollo.canbus.WheelSpeed.is_wheel_spd_fr_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_fr', full_name='apollo.canbus.WheelSpeed.wheel_direction_fr', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_fr', full_name='apollo.canbus.WheelSpeed.wheel_spd_fr', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_fl_valid', full_name='apollo.canbus.WheelSpeed.is_wheel_spd_fl_valid', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_fl', full_name='apollo.canbus.WheelSpeed.wheel_direction_fl', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_fl', full_name='apollo.canbus.WheelSpeed.wheel_spd_fl', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WHEELSPEED_WHEELSPEEDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2303,
  serialized_end=2957,
)


_SONAR = _descriptor.Descriptor(
  name='Sonar',
  full_name='apollo.canbus.Sonar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='apollo.canbus.Sonar.range', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translation', full_name='apollo.canbus.Sonar.translation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='apollo.canbus.Sonar.rotation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2959,
  serialized_end=3071,
)


_SURROUND = _descriptor.Descriptor(
  name='Surround',
  full_name='apollo.canbus.Surround',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cross_traffic_alert_left', full_name='apollo.canbus.Surround.cross_traffic_alert_left', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_traffic_alert_left_enabled', full_name='apollo.canbus.Surround.cross_traffic_alert_left_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blind_spot_left_alert', full_name='apollo.canbus.Surround.blind_spot_left_alert', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blind_spot_left_alert_enabled', full_name='apollo.canbus.Surround.blind_spot_left_alert_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_traffic_alert_right', full_name='apollo.canbus.Surround.cross_traffic_alert_right', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_traffic_alert_right_enabled', full_name='apollo.canbus.Surround.cross_traffic_alert_right_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blind_spot_right_alert', full_name='apollo.canbus.Surround.blind_spot_right_alert', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blind_spot_right_alert_enabled', full_name='apollo.canbus.Surround.blind_spot_right_alert_enabled', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar00', full_name='apollo.canbus.Surround.sonar00', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar01', full_name='apollo.canbus.Surround.sonar01', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar02', full_name='apollo.canbus.Surround.sonar02', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar03', full_name='apollo.canbus.Surround.sonar03', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar04', full_name='apollo.canbus.Surround.sonar04', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar05', full_name='apollo.canbus.Surround.sonar05', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar06', full_name='apollo.canbus.Surround.sonar06', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar07', full_name='apollo.canbus.Surround.sonar07', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar08', full_name='apollo.canbus.Surround.sonar08', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar09', full_name='apollo.canbus.Surround.sonar09', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar10', full_name='apollo.canbus.Surround.sonar10', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar11', full_name='apollo.canbus.Surround.sonar11', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar_enabled', full_name='apollo.canbus.Surround.sonar_enabled', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar_fault', full_name='apollo.canbus.Surround.sonar_fault', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar_range', full_name='apollo.canbus.Surround.sonar_range', index=22,
      number=23, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sonar', full_name='apollo.canbus.Surround.sonar', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3074,
  serialized_end=3686,
)


_LICENSE = _descriptor.Descriptor(
  name='License',
  full_name='apollo.canbus.License',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin', full_name='apollo.canbus.License.vin', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3688,
  serialized_end=3714,
)

_CHASSIS.fields_by_name['driving_mode'].enum_type = _CHASSIS_DRIVINGMODE
_CHASSIS.fields_by_name['error_code'].enum_type = _CHASSIS_ERRORCODE
_CHASSIS.fields_by_name['gear_location'].enum_type = _CHASSIS_GEARPOSITION
_CHASSIS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CHASSIS.fields_by_name['signal'].message_type = modules_dot_common_dot_proto_dot_vehicle__signal__pb2._VEHICLESIGNAL
_CHASSIS.fields_by_name['chassis_gps'].message_type = _CHASSISGPS
_CHASSIS.fields_by_name['engage_advice'].message_type = modules_dot_common_dot_proto_dot_drive__state__pb2._ENGAGEADVICE
_CHASSIS.fields_by_name['wheel_speed'].message_type = _WHEELSPEED
_CHASSIS.fields_by_name['surround'].message_type = _SURROUND
_CHASSIS.fields_by_name['license'].message_type = _LICENSE
_CHASSIS.fields_by_name['vehicle_id'].message_type = modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2._VEHICLEID
_CHASSIS_DRIVINGMODE.containing_type = _CHASSIS
_CHASSIS_ERRORCODE.containing_type = _CHASSIS
_CHASSIS_GEARPOSITION.containing_type = _CHASSIS
_CHASSISGPS.fields_by_name['quality'].enum_type = _GPSQUALITY
_WHEELSPEED.fields_by_name['wheel_direction_rr'].enum_type = _WHEELSPEED_WHEELSPEEDTYPE
_WHEELSPEED.fields_by_name['wheel_direction_rl'].enum_type = _WHEELSPEED_WHEELSPEEDTYPE
_WHEELSPEED.fields_by_name['wheel_direction_fr'].enum_type = _WHEELSPEED_WHEELSPEEDTYPE
_WHEELSPEED.fields_by_name['wheel_direction_fl'].enum_type = _WHEELSPEED_WHEELSPEEDTYPE
_WHEELSPEED_WHEELSPEEDTYPE.containing_type = _WHEELSPEED
_SONAR.fields_by_name['translation'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_SONAR.fields_by_name['rotation'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._QUATERNION
_SURROUND.fields_by_name['sonar'].message_type = _SONAR
DESCRIPTOR.message_types_by_name['Chassis'] = _CHASSIS
DESCRIPTOR.message_types_by_name['ChassisGPS'] = _CHASSISGPS
DESCRIPTOR.message_types_by_name['WheelSpeed'] = _WHEELSPEED
DESCRIPTOR.message_types_by_name['Sonar'] = _SONAR
DESCRIPTOR.message_types_by_name['Surround'] = _SURROUND
DESCRIPTOR.message_types_by_name['License'] = _LICENSE
DESCRIPTOR.enum_types_by_name['GpsQuality'] = _GPSQUALITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Chassis = _reflection.GeneratedProtocolMessageType('Chassis', (_message.Message,), {
  'DESCRIPTOR' : _CHASSIS,
  '__module__' : 'modules.canbus.proto.chassis_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Chassis)
  })
_sym_db.RegisterMessage(Chassis)

ChassisGPS = _reflection.GeneratedProtocolMessageType('ChassisGPS', (_message.Message,), {
  'DESCRIPTOR' : _CHASSISGPS,
  '__module__' : 'modules.canbus.proto.chassis_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.ChassisGPS)
  })
_sym_db.RegisterMessage(ChassisGPS)

WheelSpeed = _reflection.GeneratedProtocolMessageType('WheelSpeed', (_message.Message,), {
  'DESCRIPTOR' : _WHEELSPEED,
  '__module__' : 'modules.canbus.proto.chassis_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.WheelSpeed)
  })
_sym_db.RegisterMessage(WheelSpeed)

Sonar = _reflection.GeneratedProtocolMessageType('Sonar', (_message.Message,), {
  'DESCRIPTOR' : _SONAR,
  '__module__' : 'modules.canbus.proto.chassis_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Sonar)
  })
_sym_db.RegisterMessage(Sonar)

Surround = _reflection.GeneratedProtocolMessageType('Surround', (_message.Message,), {
  'DESCRIPTOR' : _SURROUND,
  '__module__' : 'modules.canbus.proto.chassis_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Surround)
  })
_sym_db.RegisterMessage(Surround)

License = _reflection.GeneratedProtocolMessageType('License', (_message.Message,), {
  'DESCRIPTOR' : _LICENSE,
  '__module__' : 'modules.canbus.proto.chassis_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.License)
  })
_sym_db.RegisterMessage(License)


_CHASSIS.fields_by_name['high_beam_signal']._options = None
_CHASSIS.fields_by_name['low_beam_signal']._options = None
_CHASSIS.fields_by_name['left_turn_signal']._options = None
_CHASSIS.fields_by_name['right_turn_signal']._options = None
_CHASSIS.fields_by_name['horn']._options = None
_CHASSIS.fields_by_name['disengage_status']._options = None
_CHASSIS.fields_by_name['license']._options = None
_LICENSE.fields_by_name['vin']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/localization_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/localization_config.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/localization/proto/localization_config.proto\x12\x13\x61pollo.localization\"\x94\x01\n\x12LocalizationConfig\x12X\n\x11localization_type\x18\x01 \x01(\x0e\x32\x38.apollo.localization.LocalizationConfig.LocalizationType:\x03RTK\"$\n\x10LocalizationType\x12\x07\n\x03RTK\x10\x00\x12\x07\n\x03MSF\x10\x01'
)



_LOCALIZATIONCONFIG_LOCALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='LocalizationType',
  full_name='apollo.localization.LocalizationConfig.LocalizationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RTK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=190,
  serialized_end=226,
)
_sym_db.RegisterEnumDescriptor(_LOCALIZATIONCONFIG_LOCALIZATIONTYPE)


_LOCALIZATIONCONFIG = _descriptor.Descriptor(
  name='LocalizationConfig',
  full_name='apollo.localization.LocalizationConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localization_type', full_name='apollo.localization.LocalizationConfig.localization_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALIZATIONCONFIG_LOCALIZATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=226,
)

_LOCALIZATIONCONFIG.fields_by_name['localization_type'].enum_type = _LOCALIZATIONCONFIG_LOCALIZATIONTYPE
_LOCALIZATIONCONFIG_LOCALIZATIONTYPE.containing_type = _LOCALIZATIONCONFIG
DESCRIPTOR.message_types_by_name['LocalizationConfig'] = _LOCALIZATIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalizationConfig = _reflection.GeneratedProtocolMessageType('LocalizationConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZATIONCONFIG,
  '__module__' : 'modules.localization.proto.localization_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.LocalizationConfig)
  })
_sym_db.RegisterMessage(LocalizationConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/calibration_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/calibration_table.proto',
  package='apollo.control.calibrationtable',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/control/proto/calibration_table.proto\x12\x1f\x61pollo.control.calibrationtable\"g\n\x17\x43ontrolCalibrationTable\x12L\n\x0b\x63\x61libration\x18\x01 \x03(\x0b\x32\x37.apollo.control.calibrationtable.ControlCalibrationInfo\"N\n\x16\x43ontrolCalibrationInfo\x12\r\n\x05speed\x18\x01 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x01\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x01'
)




_CONTROLCALIBRATIONTABLE = _descriptor.Descriptor(
  name='ControlCalibrationTable',
  full_name='apollo.control.calibrationtable.ControlCalibrationTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calibration', full_name='apollo.control.calibrationtable.ControlCalibrationTable.calibration', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=185,
)


_CONTROLCALIBRATIONINFO = _descriptor.Descriptor(
  name='ControlCalibrationInfo',
  full_name='apollo.control.calibrationtable.ControlCalibrationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.control.calibrationtable.ControlCalibrationInfo.speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.control.calibrationtable.ControlCalibrationInfo.acceleration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='apollo.control.calibrationtable.ControlCalibrationInfo.command', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=265,
)

_CONTROLCALIBRATIONTABLE.fields_by_name['calibration'].message_type = _CONTROLCALIBRATIONINFO
DESCRIPTOR.message_types_by_name['ControlCalibrationTable'] = _CONTROLCALIBRATIONTABLE
DESCRIPTOR.message_types_by_name['ControlCalibrationInfo'] = _CONTROLCALIBRATIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlCalibrationTable = _reflection.GeneratedProtocolMessageType('ControlCalibrationTable', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLCALIBRATIONTABLE,
  '__module__' : 'modules.control.proto.calibration_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.calibrationtable.ControlCalibrationTable)
  })
_sym_db.RegisterMessage(ControlCalibrationTable)

ControlCalibrationInfo = _reflection.GeneratedProtocolMessageType('ControlCalibrationInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLCALIBRATIONINFO,
  '__module__' : 'modules.control.proto.calibration_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.calibrationtable.ControlCalibrationInfo)
  })
_sym_db.RegisterMessage(ControlCalibrationInfo)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/fusion_params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/fusion_params.proto',
  package='apollo.v2x.ft.fusion',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/v2x/proto/fusion_params.proto\x12\x14\x61pollo.v2x.ft.fusion\"\x1d\n\x08KMParams\x12\x11\n\tmin_score\x18\x01 \x01(\x01\"\x1d\n\x05Param\x12\t\n\x01k\x18\x01 \x01(\x01\x12\t\n\x01\x62\x18\x02 \x01(\x01\"R\n\x11SingleCameraParam\x12\x11\n\tcamera_id\x18\x01 \x01(\x05\x12*\n\x05param\x18\x02 \x03(\x0b\x32\x1b.apollo.v2x.ft.fusion.Param\"\xdc\x01\n\x0bScoreParams\x12\x12\n\nprob_scale\x18\x01 \x01(\x01\x12\x1a\n\x12max_match_distance\x18\x02 \x01(\x01\x12\x11\n\tmin_score\x18\x03 \x01(\x01\x12\'\n\x18use_mahalanobis_distance\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x19\n\ncheck_type\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x46\n\x10\x63onfidence_level\x18\x06 \x01(\x0e\x32%.apollo.v2x.ft.fusion.ConfidenceLevel:\x05\x43\x39\x37\x35P\"\xba\x01\n\x0c\x46usionParams\x12>\n\rfusion_params\x18\x01 \x03(\x0b\x32\'.apollo.v2x.ft.fusion.SingleCameraParam\x12\x31\n\tkm_params\x18\x02 \x01(\x0b\x32\x1e.apollo.v2x.ft.fusion.KMParams\x12\x37\n\x0cscore_params\x18\x03 \x02(\x0b\x32!.apollo.v2x.ft.fusion.ScoreParams*:\n\x0f\x43onfidenceLevel\x12\x08\n\x04\x43\x39\x30P\x10\x00\x12\x08\n\x04\x43\x39\x35P\x10\x01\x12\t\n\x05\x43\x39\x37\x35P\x10\x02\x12\x08\n\x04\x43\x39\x39P\x10\x03'
)

_CONFIDENCELEVEL = _descriptor.EnumDescriptor(
  name='ConfidenceLevel',
  full_name='apollo.v2x.ft.fusion.ConfidenceLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='C90P', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C95P', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C975P', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C99P', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=621,
  serialized_end=679,
)
_sym_db.RegisterEnumDescriptor(_CONFIDENCELEVEL)

ConfidenceLevel = enum_type_wrapper.EnumTypeWrapper(_CONFIDENCELEVEL)
C90P = 0
C95P = 1
C975P = 2
C99P = 3



_KMPARAMS = _descriptor.Descriptor(
  name='KMParams',
  full_name='apollo.v2x.ft.fusion.KMParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_score', full_name='apollo.v2x.ft.fusion.KMParams.min_score', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=92,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='apollo.v2x.ft.fusion.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='k', full_name='apollo.v2x.ft.fusion.Param.k', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='apollo.v2x.ft.fusion.Param.b', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=123,
)


_SINGLECAMERAPARAM = _descriptor.Descriptor(
  name='SingleCameraParam',
  full_name='apollo.v2x.ft.fusion.SingleCameraParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='apollo.v2x.ft.fusion.SingleCameraParam.camera_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='param', full_name='apollo.v2x.ft.fusion.SingleCameraParam.param', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=207,
)


_SCOREPARAMS = _descriptor.Descriptor(
  name='ScoreParams',
  full_name='apollo.v2x.ft.fusion.ScoreParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prob_scale', full_name='apollo.v2x.ft.fusion.ScoreParams.prob_scale', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_match_distance', full_name='apollo.v2x.ft.fusion.ScoreParams.max_match_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_score', full_name='apollo.v2x.ft.fusion.ScoreParams.min_score', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_mahalanobis_distance', full_name='apollo.v2x.ft.fusion.ScoreParams.use_mahalanobis_distance', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_type', full_name='apollo.v2x.ft.fusion.ScoreParams.check_type', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence_level', full_name='apollo.v2x.ft.fusion.ScoreParams.confidence_level', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=430,
)


_FUSIONPARAMS = _descriptor.Descriptor(
  name='FusionParams',
  full_name='apollo.v2x.ft.fusion.FusionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fusion_params', full_name='apollo.v2x.ft.fusion.FusionParams.fusion_params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='km_params', full_name='apollo.v2x.ft.fusion.FusionParams.km_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score_params', full_name='apollo.v2x.ft.fusion.FusionParams.score_params', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=619,
)

_SINGLECAMERAPARAM.fields_by_name['param'].message_type = _PARAM
_SCOREPARAMS.fields_by_name['confidence_level'].enum_type = _CONFIDENCELEVEL
_FUSIONPARAMS.fields_by_name['fusion_params'].message_type = _SINGLECAMERAPARAM
_FUSIONPARAMS.fields_by_name['km_params'].message_type = _KMPARAMS
_FUSIONPARAMS.fields_by_name['score_params'].message_type = _SCOREPARAMS
DESCRIPTOR.message_types_by_name['KMParams'] = _KMPARAMS
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['SingleCameraParam'] = _SINGLECAMERAPARAM
DESCRIPTOR.message_types_by_name['ScoreParams'] = _SCOREPARAMS
DESCRIPTOR.message_types_by_name['FusionParams'] = _FUSIONPARAMS
DESCRIPTOR.enum_types_by_name['ConfidenceLevel'] = _CONFIDENCELEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KMParams = _reflection.GeneratedProtocolMessageType('KMParams', (_message.Message,), {
  'DESCRIPTOR' : _KMPARAMS,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.KMParams)
  })
_sym_db.RegisterMessage(KMParams)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.Param)
  })
_sym_db.RegisterMessage(Param)

SingleCameraParam = _reflection.GeneratedProtocolMessageType('SingleCameraParam', (_message.Message,), {
  'DESCRIPTOR' : _SINGLECAMERAPARAM,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.SingleCameraParam)
  })
_sym_db.RegisterMessage(SingleCameraParam)

ScoreParams = _reflection.GeneratedProtocolMessageType('ScoreParams', (_message.Message,), {
  'DESCRIPTOR' : _SCOREPARAMS,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.ScoreParams)
  })
_sym_db.RegisterMessage(ScoreParams)

FusionParams = _reflection.GeneratedProtocolMessageType('FusionParams', (_message.Message,), {
  'DESCRIPTOR' : _FUSIONPARAMS,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.FusionParams)
  })
_sym_db.RegisterMessage(FusionParams)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/routing/proto/default_routing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/routing/proto/default_routing.proto',
  package='apollo.routing',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+modules/routing/proto/default_routing.proto\x12\x0e\x61pollo.routing\x1a#modules/common/proto/geometry.proto\"F\n\x0e\x44\x65\x66\x61ultRouting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x05point\x18\x02 \x03(\x0b\x32\x17.apollo.common.PointENU\"I\n\x0f\x44\x65\x66\x61ultRoutings\x12\x36\n\x0e\x64\x65\x66\x61ultrouting\x18\x01 \x03(\x0b\x32\x1e.apollo.routing.DefaultRouting'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_DEFAULTROUTING = _descriptor.Descriptor(
  name='DefaultRouting',
  full_name='apollo.routing.DefaultRouting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.routing.DefaultRouting.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.routing.DefaultRouting.point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=170,
)


_DEFAULTROUTINGS = _descriptor.Descriptor(
  name='DefaultRoutings',
  full_name='apollo.routing.DefaultRoutings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='defaultrouting', full_name='apollo.routing.DefaultRoutings.defaultrouting', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=245,
)

_DEFAULTROUTING.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_DEFAULTROUTINGS.fields_by_name['defaultrouting'].message_type = _DEFAULTROUTING
DESCRIPTOR.message_types_by_name['DefaultRouting'] = _DEFAULTROUTING
DESCRIPTOR.message_types_by_name['DefaultRoutings'] = _DEFAULTROUTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DefaultRouting = _reflection.GeneratedProtocolMessageType('DefaultRouting', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTROUTING,
  '__module__' : 'modules.routing.proto.default_routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.DefaultRouting)
  })
_sym_db.RegisterMessage(DefaultRouting)

DefaultRoutings = _reflection.GeneratedProtocolMessageType('DefaultRoutings', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTROUTINGS,
  '__module__' : 'modules.routing.proto.default_routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.DefaultRoutings)
  })
_sym_db.RegisterMessage(DefaultRoutings)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/preprocessor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import drive_state_pb2 as modules_dot_common_dot_proto_dot_drive__state__pb2
from modules.control.proto import input_debug_pb2 as modules_dot_control_dot_proto_dot_input__debug__pb2
from modules.control.proto import local_view_pb2 as modules_dot_control_dot_proto_dot_local__view__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/preprocessor.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/control/proto/preprocessor.proto\x12\x0e\x61pollo.control\x1a!modules/common/proto/header.proto\x1a&modules/common/proto/drive_state.proto\x1a\'modules/control/proto/input_debug.proto\x1a&modules/control/proto/local_view.proto\"\x96\x02\n\x0cPreprocessor\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12-\n\nlocal_view\x18\x02 \x01(\x0b\x32\x19.apollo.control.LocalView\x12\x32\n\rengage_advice\x18\x04 \x01(\x0b\x32\x1b.apollo.common.EngageAdvice\x12/\n\x0binput_debug\x18\x05 \x01(\x0b\x32\x1a.apollo.control.InputDebug\x12\x1f\n\x10received_pad_msg\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x14\n\x05\x65stop\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x14\n\x0c\x65stop_reason\x18\x08 \x01(\t'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_drive__state__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_input__debug__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_local__view__pb2.DESCRIPTOR,])




_PREPROCESSOR = _descriptor.Descriptor(
  name='Preprocessor',
  full_name='apollo.control.Preprocessor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.control.Preprocessor.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_view', full_name='apollo.control.Preprocessor.local_view', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engage_advice', full_name='apollo.control.Preprocessor.engage_advice', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_debug', full_name='apollo.control.Preprocessor.input_debug', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received_pad_msg', full_name='apollo.control.Preprocessor.received_pad_msg', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estop', full_name='apollo.control.Preprocessor.estop', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estop_reason', full_name='apollo.control.Preprocessor.estop_reason', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=495,
)

_PREPROCESSOR.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PREPROCESSOR.fields_by_name['local_view'].message_type = modules_dot_control_dot_proto_dot_local__view__pb2._LOCALVIEW
_PREPROCESSOR.fields_by_name['engage_advice'].message_type = modules_dot_common_dot_proto_dot_drive__state__pb2._ENGAGEADVICE
_PREPROCESSOR.fields_by_name['input_debug'].message_type = modules_dot_control_dot_proto_dot_input__debug__pb2._INPUTDEBUG
DESCRIPTOR.message_types_by_name['Preprocessor'] = _PREPROCESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Preprocessor = _reflection.GeneratedProtocolMessageType('Preprocessor', (_message.Message,), {
  'DESCRIPTOR' : _PREPROCESSOR,
  '__module__' : 'modules.control.proto.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.Preprocessor)
  })
_sym_db.RegisterMessage(Preprocessor)


# @@protoc_insertion_point(module_scope)
